#!/usr/bin/env python3

# This program receives text files as input and as an output generates 
# the code(s) of the language(s) in which the text(s) was/were written. 
# It is a dummy baseline that returns a random language among the 
# possible languages.

import sys
import random
import argparse

# List of possible languages
LANGUAGES={}
LANGUAGES['european'] = ['bg','cs','da','de','el','en','es','et','fi','fr','hu',
             'it','lt','lv','nl','pl','pt','ro','sk','sl','sv' ]
LANGUAGES['similar'] = ['bs','es-AR','es-ES','es-MX','fr-CA','fr-FR','hr','id',
                     'my','pt-BR','pt-PT','sr',]
LANGUAGES['arabic'] = ['EGY', 'GLF', 'NOR', 'MSA', 'LAV']             

# Treat list of arguments in command line: must be valid filenames
parser = argparse.ArgumentParser(description='Guess the language of a text. \
Input is a list of sentences in different languages, one per line. Everything \
after tabulation (TAB) will be ignored and replaced by the language code.')
parser.add_argument('dataset',choices=['european', 'similar', 'arabic'],
                   help='Name of the dataset: european, similar or arabic')
parser.add_argument('textfile', type=argparse.FileType('r'),
                   help='Text file, with one sentence per line, UTF-8')
args = parser.parse_args()



# For each text file in argument list
for text in args.textfile :
  # Print the filename and a random language name
  file_line = text.strip().split("\t")[0]
  print("\t".join([file_line,random.choice(LANGUAGES[args.dataset])]))
